%if 0%{?fedora} || 0%{?rhel} >= 7
%global __python_sitearch %{python2_sitearch}
%else
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%global __python_sitearch %{python_sitearch}
%endif

Name:		liblinear
Version:	1.93
Release:	3%{?dist}
Summary:	Library for Large Linear Classification
%{?el5:Group:	System Environment/Libraries}

License:	BSD
URL:		http://www.csie.ntu.edu.tw/~cjlin/%{name}
Source0:	%{url}/%{name}-%{version}.tar.gz
Source1:	%{url}/index.html
Source2:	%{url}/FAQ.html
Source3:	%{url}/exp.html
Source4:	http://www.csie.ntu.edu.tw/~cjlin/papers/%{name}.pdf

# simple fixes, not needed by upstream
Patch0:		liblinear-adapt_makefile.patch
Patch1:		liblinear-fix_compiler_warnings.patch

%{?el5:BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)}
BuildRequires:	blas-devel
BuildRequires:	python2-devel

%if 0%{?fedora} || 0%{?rhel} >= 7
BuildRequires:	python3-devel
%endif


%description
%{name} is an open source library for large-scale linear classification.
It supports logistic regression and linear support vector machines.  It
provides easy-to-use command-line tools and library calls for users and
developers.  Comprehensive documents are available for both beginners
and advanced users.

Experiments demonstrate that %{name} is very efficient on large sparse
data sets.  %{name} is the winner of ICML 2008 large-scale learning
challenge (linear SVM track).  It is also used for winning KDD Cup 2010.


%package cli
Summary:	CLI-tools for %{name}
%{?el5:Group:	Applications/Engineering}

Requires:	%{name}%{?_isa} = %{version}-%{release}

%description cli
This package contains cli-tools for use with %{name}.

For further information read "3.1 Practical Usage" from the pdf included
in the %{name}-doc package.


%package devel
Summary:	Development files for %{name}
%{?el5:Group:	Development/Libraries}

Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.


%package doc
Summary:	Documentation files for %{name}
%{?el5:Group:	Documentation}

%{!?el5:BuildArch:	noarch}

%description doc
The %{name}-doc package contains some brief documentation for developing
applications that use %{name}.


%package -n python-%{name}
Summary:	Python bindings for %{name}
%{?el5:Group:	System Environment/Libraries}

Requires:	%{name}%{?_isa} = %{version}-%{release}

%description  -n python-%{name}
This package contains bindings for developing Python applications that
use %{name}.

For further information read "README.python" included in the
%{name}-doc package.


%if 0%{?fedora} || 0%{?rhel} >= 7
%package -n python3-%{name}
Summary:	Python3 bindings for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description  -n python3-%{name}
This package contains bindings for developing Python3 applications that
use %{name}.

For further information read "README.python" included in the
%{name}-doc package.
%endif


%prep
%setup -q
%patch0 -p1
%patch1 -p1

# pull in other sources
install -pm 0644 %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} .

# remove bundled stuff
rm -rf blas/ matlab/ windows/ Makefile.*

# add pkg-config file
cat << EOF >> %{name}.pc
#################################
# Pkg-Config file for %{name} #
#################################

Name: %{name}
Description: Library for Large Linear Classification
URL: %{url}
Version: %{version}

prefix=%{_prefix}
includedir=%{_includedir}

Cflags: -I\$\{includedir\}/liblinear
Libs: -llinear
EOF

# rename python/README for inclusion in doc
mv python/README README.python

# remove hashbang from lib's files
sed -i -e '/#!\//d' python/*.py


%build
%configure ||:
make %{?_smp_mflags}


%install
%{?el5:rm -rf %{buildroot}}

# no install-target in Makefile
mkdir -p %{buildroot}%{_bindir}			\
	%{buildroot}%{_libdir}/pkgconfig	\
	%{buildroot}%{_includedir}/%{name}	\
	%{buildroot}%{__python_sitearch}

install -pm 0755 predict %{buildroot}%{_bindir}/%{name}-predict
install -pm 0755 train %{buildroot}%{_bindir}/%{name}-train
install -pm 0755 %{name}.so.1 %{buildroot}%{_libdir}
ln -s %{name}.so.1 %{buildroot}%{_libdir}/%{name}.so
install -pm 0644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig
install -pm 0644 {linear,tron}.h %{buildroot}%{_includedir}/%{name}

install -pm 0644 python/*.py %{buildroot}%{__python_sitearch}

%if 0%{?fedora} || 0%{?rhel} >= 7
mkdir -p %{buildroot}%{python3_sitearch}
install -pm 0644 python/*.py %{buildroot}%{python3_sitearch}
%endif


%clean
%{?el5:rm -rf %{buildroot}}


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig


%files
%doc COPYRIGHT
%{_libdir}/%{name}.so.*

%files cli
%doc heart_scale
%{_bindir}/*

%files devel
%{_includedir}/*
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%doc COPYRIGHT README* {predict,train}.c *.html *.pdf

%files -n python-%{name}
%{__python_sitearch}/*

%if 0%{?fedora} || 0%{?rhel} >= 7
%files -n python3-%{name}
%{python3_sitearch}/*
%endif


%changelog
* Wed Oct 02 2013 Björn Esser <bjoern.esser@gmail.com> - 1.93-3
- adaptions for new Python-guidelines
- generate .pc-file on-the-fly
- minor cleanup

* Mon Aug 12 2013 Björn Esser <bjoern.esser@gmail.com> - 1.93-2
- build arched python-plugins
- nuke hashbang from python-plugins

* Sun Aug 11 2013 Björn Esser <bjoern.esser@gmail.com> - 1.93-1
- Initial rpm release (#995864)
